<?php

/**
 * The file that defines the core plugin class
 *
 * A class definition that includes attributes and functions used across both the
 * public-facing side of the site and the admin area.
 *
 * @link       http://www.europadns.com/
 * @since      1.0.0
 *
 * @package    quad_shortcodes
 * @subpackage quad_shortcodes/includes
 */

/**
 * The core plugin class.
 *
 * This is used to define internationalization, admin-specific hooks, and
 * public-facing site hooks.
 *
 * Also maintains the unique identifier of this plugin as well as the current
 * version of the plugin.
 *
 * @since      1.0.0
 * @package    quad_shortcodes
 * @subpackage quad_shortcodes/includes
 * @author     Europadns <nicolae@europadns.com>
 */
class quad_shortcodes {

    /**
     * The loader that's responsible for maintaining and registering all hooks that power
     * the plugin.
     *
     * @since    1.0.0
     * @access   protected
     * @var      quad_shortcodes_Loader    $loader    Maintains and registers all hooks for the plugin.
     */
    protected $loader;

    /**
     * The unique identifier of this plugin.
     *
     * @since    1.0.0
     * @access   protected
     * @var      string    $plugin_name    The string used to uniquely identify this plugin.
     */
    protected $quad_shortcodes;

    /**
     * The current version of the plugin.
     *
     * @since    1.0.0
     * @access   protected
     * @var      string    $version    The current version of the plugin.
     */
    protected $version;

    /**
     * Define the core functionality of the plugin.
     *
     * Set the plugin name and the plugin version that can be used throughout the plugin.
     * Load the dependencies, define the locale, and set the hooks for the admin area and
     * the public-facing side of the site.
     *
     * @since    1.0.0
     */
    public function __construct() {

        $this->quad_shortcodes = 'quad-shortcodes';
        $this->version = '1.0.0';

        $this->load_dependencies();
        $this->set_locale();
        $this->quad_shortcodes_initiate_shortcodes();
    }

    /**
     * Load the required dependencies for this plugin.
     *
     * Include the following files that make up the plugin:
     *
     * - quad_shortcodes_Loader. Orchestrates the hooks of the plugin.
     * - quad_shortcodes_i18n. Defines internationalization functionality.
     *
     * Create an instance of the loader which will be used to register the hooks
     * with WordPress.
     *
     * @since    1.0.0
     * @access   private
     */
    private function load_dependencies() {

        /**
         * The class responsible for orchestrating the actions and filters of the
         * core plugin.
         */
        require_once plugin_dir_path(dirname(__FILE__)) . 'includes/class-quad-shortcodes-loader.php';

        /**
         * The class responsible for defining internationalization functionality
         * of the plugin.
         */
        require_once plugin_dir_path(dirname(__FILE__)) . 'includes/class-quad-shortcodes-i18n.php';

        $this->loader = new quad_shortcodes_Loader();
    }

    /**
     * Define the locale for this plugin for internationalization.
     *
     * Uses the quad_shortcodes_i18n class in order to set the domain and to register the hook
     * with WordPress.
     *
     * @since    1.0.0
     * @access   private
     */
    private function set_locale() {

        $plugin_i18n = new quad_shortcodes_i18n();
        $plugin_i18n->set_domain($this->get_quad_shortcodes());

        $this->loader->add_action('plugins_loaded', $plugin_i18n, 'load_plugin_textdomain');
    }

    /**
     * Run the loader to execute all of the hooks with WordPress.
     *
     * @since    1.0.0
     */
    public function run() {
        $this->loader->run();
    }

    /**
     * The name of the plugin used to uniquely identify it within the context of
     * WordPress and to define internationalization functionality.
     *
     * @since     1.0.0
     * @return    string    The name of the plugin.
     */
    public function get_quad_shortcodes() {
        return $this->quad_shortcodes;
    }

    /**
     * The reference to the class that orchestrates the hooks with the plugin.
     *
     * @since     1.0.0
     * @return    quad_shortcodes_Loader    Orchestrates the hooks of the plugin.
     */
    public function get_loader() {
        return $this->loader;
    }

    /**
     * Retrieve the version number of the plugin.
     *
     * @since     1.0.0
     * @return    string    The version number of the plugin.
     */
    public function get_version() {
        return $this->version;
    }

    public function quad_shortcodes_initiate_shortcodes() {
        
    }

}
function quad_shortcodes_widgets_init1() {
    register_widget('quad_flickr_widget');
}

add_action('widgets_init', 'quad_shortcodes_widgets_init1');
//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//
//                       Flickr Widget
//
/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
class quad_flickr_widget extends WP_Widget {

    function __construct() {
        parent::__construct(
                'quad_flickr_widget', esc_html__('Quad - Flickr', 'quad-shortcodes'), array(
            'description' => esc_html__('Flickr gallery widget', 'quad-shortcodes'),)
        );
    }

    public function widget($args, $instance) {
        $user = apply_filters('widget_user', $instance['user']);
        $title = apply_filters('widget_title', $instance['title']);
        $images = apply_filters('widget_images', $instance['images']);

        if (trim($images) != '') {
            if (preg_match("/[^0-9]/", $images)) {
                $images = 1;
            }
        } else {
            $images = 1;
        }

        echo wp_kses_post($args['before_widget']);
        ?>
        <div class="quad_widget_flickr">
            <?php
            if (trim($title) != '') {
                echo wp_kses_post($args['before_title']);
                echo esc_html($title);
                echo wp_kses_post($args['after_title']);
            }
            ?>
            <div class="flickr-feed">
                <?php if (trim($user) != ''): ?>
                    <script type="text/javascript" src="//www.flickr.com/badge_code_v2.gne?count=<?php echo esc_attr($images); ?>&amp;display=latest&amp;size=s&amp;layout=x&amp;source=user&amp;user=<?php echo esc_attr($user); ?>"></script>                    
                <?php endif; ?>
            </div>
        </div>
        <br class="clear">
        <?php
        echo wp_kses_post($args['after_widget']);
    }

    public function form($instance) {
        if (isset($instance['title'])) {
            $title = $instance['title'];
        } else {
            $title = '';
        }
        ?>
        <p>
            <label for="<?php echo sanitize_html_class($this->get_field_id('title')); ?>"><?php esc_html_e('Title:', 'quad-shortcodes'); ?></label>
            <input class="widefat" 
                   id="<?php echo sanitize_html_class($this->get_field_id('title')); ?>" 
                   name="<?php echo esc_attr($this->get_field_name('title')); ?>" 
                   type="text" 
                   value="<?php echo esc_attr($title); ?>" />
        </p>

        <?php
        if (isset($instance['user'])) {
            $user = $instance['user'];
        } else {
            $user = '';
        }
        ?>
        <p>
            <label for="<?php echo sanitize_html_class($this->get_field_id('user')); ?>"><?php esc_html_e('Flicker User ID:', 'quad-shortcodes'); ?></label>
            <input class="widefat" 
                   id="<?php echo sanitize_html_class($this->get_field_id('user')); ?>" 
                   name="<?php echo esc_attr($this->get_field_name('user')); ?>" 
                   type="text" 
                   value="<?php echo esc_attr($user); ?>" />
            <label><?php esc_html_e('Use ', 'quad-shortcodes'); ?><a href='//idgettr.com/' target='_blank'>idgettr.com</a><?php esc_html_e(' to get the Flicker ID number.', 'quad-shortcodes'); ?></label>
        </p>

        <?php
        if (isset($instance['images'])) {
            $images = $instance['images'];
        } else {
            $images = '9';
        }
        ?>
        <p>
            <label for="<?php echo sanitize_html_class($this->get_field_id('images')); ?>"><?php esc_html_e('Number of images:', 'quad-shortcodes'); ?></label>
            <input class="widefat" 
                   id="<?php echo sanitize_html_class($this->get_field_id('images')); ?>" 
                   name="<?php echo esc_attr($this->get_field_name('images')); ?>" 
                   type="text" 
                   value="<?php echo esc_attr($images); ?>" />
        </p>

        <?php
    }

    public function update($new_instance, $old_instance) {
        $instance = array();
        $instance['user'] = (!empty($new_instance['user']) ) ? strip_tags($new_instance['user']) : '';
        $instance['title'] = (!empty($new_instance['title']) ) ? strip_tags($new_instance['title']) : '';
        $instance['images'] = (!empty($new_instance['images']) ) ? strip_tags($new_instance['images']) : '';
        return $instance;
    }

}
