<?php

/**
 * ReduxFramework Config File
 */
if (!class_exists('Redux')) {
    return;
}


// This is your option name where all the Redux data is stored.
$opt_name = "quad_theme_options";


// If Redux is running as a plugin, this will remove the demo notice and links
add_action('redux/loaded', 'quad_remove_demo');

$theme = wp_get_theme(); // For use with some settings. Not necessary.

$args = array(
    // TYPICAL -> Change these values as you need/desire
    'opt_name' => $opt_name,
    // This is where your data is stored in the database and also becomes your global variable name.
    'display_name' => $theme->get('Name'),
    // Name that appears at the top of your panel
    'display_version' => $theme->get('Version'),
    // Version that appears at the top of your panel
    'menu_type' => 'menu',
    //Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
    'allow_sub_menu' => true,
    // Show the sections below the admin menu item or not
    'menu_title' => esc_html__('Theme Options', 'quad-wp'),
    'page_title' => esc_html__('Theme Options', 'quad-wp'),
    'google_api_key' => '',
    // Set it you want google fonts to update weekly. A google_api_key value is required.
    'google_update_weekly' => false,
    // Must be defined to add google fonts to the typography module
    'async_typography' => true,
    // Use a asynchronous font on the front end or font string
    'admin_bar' => true,
    // Show the panel pages on the admin bar
    'admin_bar_icon' => 'dashicons-portfolio',
    // Choose an icon for the admin bar menu
    'admin_bar_priority' => 50,
    // Choose an priority for the admin bar menu
    'global_variable' => '',
    // Set a different name for your global variable other than the opt_name
    'dev_mode' => false,
    // Show the time the page took to load, etc
    'update_notice' => false,
    // If dev_mode is enabled, will notify developer of updated versions available in the GitHub Repo
    'customizer' => true,
    // Enable basic customizer support
    // OPTIONAL -> Give you extra features
    'page_priority' => 57,
    // Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
    'page_parent' => 'themes.php',
    'page_permissions' => 'manage_options',
    // Permissions needed to access the options panel.
    'menu_icon' => '',
    // Specify a custom URL to an icon
    'last_tab' => '',
    // Force your panel to always open to a specific tab (by id)
    'page_icon' => 'icon-themes',
    // Icon displayed in the admin panel next to your menu_title
    'page_slug' => '',
    // Page slug used to denote the panel, will be based off page title then menu title then opt_name if not provided
    'save_defaults' => true,
    // On load save the defaults to DB before user clicks save or not
    'default_show' => false,
    // If true, shows the default value next to each field that is not the default value.
    'default_mark' => '',
    // What to print by the field's title if the value shown is default. Suggested: *
    'show_import_export' => true,
    // Shows the Import/Export panel when not used as a field.
    // CAREFUL -> These options are for advanced use only
    'transient_time' => 60 * MINUTE_IN_SECONDS,
    'output' => true,
    // Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
    'output_tag' => true,
    // Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
    'database' => '',
    // possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!
    'system_info' => false,
    'hints' => array(
        'icon' => 'el el-question-sign',
        'icon_position' => 'right',
        'icon_color' => 'lightgray',
        'icon_size' => 'normal',
        'tip_style' => array(
            'color' => 'red',
            'shadow' => true,
            'rounded' => false,
            'style' => '',
        ),
        'tip_position' => array(
            'my' => 'top left',
            'at' => 'bottom right',
        ),
        'tip_effect' => array(
            'show' => array(
                'effect' => 'slide',
                'duration' => '500',
                'event' => 'mouseover',
            ),
            'hide' => array(
                'effect' => 'slide',
                'duration' => '500',
                'event' => 'click mouseleave',
            ),
        ),
    )
);

Redux::setArgs($opt_name, $args);

/*
 * ---> END ARGUMENTS
 */


/*
 * ---> START HELP TABS
 */

$tabs = array(
    array(
        'id' => 'redux-help-tab-1',
        'title' => esc_html__('Theme Information 1', 'quad-wp'),
        'content' => esc_html__('This is the tab content, HTML is allowed.', 'quad-wp')
    ),
    array(
        'id' => 'redux-help-tab-2',
        'title' => esc_html__('Theme Information 2', 'quad-wp'),
        'content' => esc_html__('This is the tab content, HTML is allowed.', 'quad-wp')
    )
);
Redux::setHelpTab($opt_name, $tabs);

// Set the help sidebar
$content = esc_html__('This is the sidebar content, HTML is allowed.', 'quad-wp');
Redux::setHelpSidebar($opt_name, $content);


// -> START Basic Fields

Redux::setSection($opt_name, array(
    'icon' => 'el-icon-cogs',
    'title' => esc_html__('General', 'quad-wp'),
    'subsection' => false,
    'fields' => array(
        array(
            'id' => 'quad-googlemaps-api',
            'type' => 'text',
            'title' => esc_html__('Google Maps API Key', 'quad-wp'),
            'subtitle' => esc_html__('This field is not necessary if you do not use Google Maps', 'quad-wp'),
            'desc' => esc_html__('New websites since July 2016 require an API key to use Google Maps, please insert here the key you can get from this link: https://developers.google.com/maps/documentation/javascript/get-api-key#get-an-api-key', 'quad-wp')
        ),
        array(
            'id' => 'quad-404-selection',
            'type' => 'select',
            'title' => esc_html__('404 Page Selection', 'quad-wp'),
            'subtitle' => esc_html__('Can replace the page displayed when error 404 occurs', 'quad-wp'),
            'desc' => esc_html__('Chose a page for 404 error', 'quad-wp'),
            'options' => quad_pages_list(),
            'default' => 'default',
        ),
        array(
            'id' => 'quad-search-sidebar',
            'type' => 'select',
            'data' => 'sidebars',
            'title' => esc_html__('Search Page Sidebar Selection', 'quad-wp'),
            'subtitle' => esc_html__('Chose a sidebar for search page', 'quad-wp'),
            'desc' => esc_html__('Chose a sidebar for search page', 'quad-wp'),
            'default' => 'none',
        ),
        array(
            'id' => 'quad-search-sidebar-position',
            'type' => 'button_set',
            'title' => esc_html__('Search Page Sidebar Position', 'quad-wp'),
            'subtitle' => esc_html__('Chose a sidebar positon for search page', 'quad-wp'),
            'desc' => esc_html__('Chose a sidebar positon for search page', 'quad-wp'),
            'options' => array(
                'left' => 'Left',
                'none' => 'None',
                'right' => 'Right'
            ),
            'default' => 'none'
        ),
        array(
            'id' => 'quad-font-switch',
            'type' => 'button_set',
            'title' => esc_html__('Custom Google font', 'quad-wp'),
            'subtitle' => esc_html__('Enable or disable custom font selection', 'quad-wp'),
            'desc' => esc_html__('It will show the font fields if enabled', 'quad-wp'),
            'options' => array(
                '1' => esc_html__('Enable', 'quad-wp'),
                '2' => esc_html__('Disable', 'quad-wp')
            ),
            'default' => '2'
        ),
        array(
            'id' => 'quad-custom-font',
            'type' => 'text',
            'required' => array('quad-font-switch', 'equals', '1'),
            'title' => esc_html__('Primary Google Font URL', 'quad-wp'),
            'subtitle' => esc_html__('This will replace the theme Roboto font', 'quad-wp'),
            'desc' => esc_html__('Example of Google font URL: https://fonts.googleapis.com/css?family=Open+Sans:400,700,700italic --->You can choose Google fonts from: https://www.google.com/fonts', 'quad-wp')
        ),
        array(
            'id' => 'quad-custom-font2',
            'type' => 'text',
            'required' => array('quad-font-switch', 'equals', '1'),
            'title' => esc_html__('Secondary Google Font URL', 'quad-wp'),
            'subtitle' => esc_html__('This will replace the theme Open Sans font', 'quad-wp'),
            'desc' => esc_html__('Example of Google font URL: https://fonts.googleapis.com/css?family=Open+Sans:400,700,700italic --->You can choose Google fonts from: https://www.google.com/fonts', 'quad-wp')
        ),
        array(
            'id' => 'quad-custom-css',
            'type' => 'textarea',
            'title' => esc_html__('Custom CSS', 'quad-wp'),
            'subtitle' => esc_html__('Only CSS code allowed', 'quad-wp'),
            'desc' => esc_html__('This field is CSS validated.', 'quad-wp'),
            'validate' => 'css',
        ),
        array(
            'id' => 'quad-boxed-switch',
            'type' => 'button_set',
            'title' => esc_html__('Boxed mode for all pages', 'quad-wp'),
            'subtitle' => esc_html__('Enable or disable', 'quad-wp'),
            'desc' => esc_html__('Enable or disable the boxed mode for all pages', 'quad-wp'),
            'options' => array(
                '1' => 'Enable',
                '2' => 'Disable'
            ),
            'default' => '2'
        ),
        array(
            'id' => 'quad-boxed-size',
            'type' => 'slider',
            'title' => esc_html__('Boxed content width', 'quad-wp'),
            'subtitle' => esc_html__('Adjust the boxed content width', 'quad-wp'),
            "default" => 1340,
            "min" => 10,
            "step" => 1,
            "max" => 1900,
            'display_value' => 'text'
        ),
        array('id' => 'quad-boxed-background',
            'type' => 'background',
            'title' => esc_html__('Boxed mode options', 'quad-wp'),
            'desc' => esc_html__('Select a color or image for the background', 'quad-wp'),
            'transparent' => false,
            'preview_media' => true,
            'default' => array(
                'background-image' => get_template_directory_uri() . '/assets/images/boxed-bg.png',
                'background-repeat' => 'repeat',
                'background-position' => 'center center'
            )
        ),
    )
));

Redux::setSection($opt_name, array(
    'icon' => 'el-icon-home',
    'title' => esc_html__('Header', 'quad-wp'),
    'subsection' => false,
    'fields' => array(
        array(
            'id' => 'quad-header-stickyheader-toggle',
            'type' => 'button_set',
            'title' => esc_html__('Sticky Header', 'quad-wp'),
            'subtitle' => esc_html__('Enable or disable the sticky header', 'quad-wp'),
            'desc' => esc_html__('Toggle On or Off', 'quad-wp'),
            'options' => array(
                '1' => esc_html__('On', 'quad-wp'),
                '2' => esc_html__('Off', 'quad-wp')
            ),
            'default' => '1'
        ),
        array(
            'id' => 'quad-header-search-toggle',
            'type' => 'button_set',
            'title' => esc_html__('Header Search', 'quad-wp'),
            'subtitle' => esc_html__('Enable or disable the header search', 'quad-wp'),
            'desc' => esc_html__('Toggle On or Off', 'quad-wp'),
            'options' => array(
                '1' => esc_html__('On', 'quad-wp'),
                '2' => esc_html__('Off', 'quad-wp')
            ),
            'default' => '1'
        ),
        array(
            'id' => 'quad-cart-toggle',
            'type' => 'button_set',
            'title' => esc_html__('Header Woocommer cart', 'quad-wp'),
            'subtitle' => esc_html__('Enable or disable the header cart', 'quad-wp'),
            'desc' => esc_html__('Available only when Woocommerce plugin is installed', 'quad-wp'),
            'options' => array(
                '1' => esc_html__('On', 'quad-wp'),
                '2' => esc_html__('Off', 'quad-wp')
            ),
            'default' => '1'
        ),
        array(
            'id' => 'quad-header-logo',
            'type' => 'media',
            'url' => true,
            'title' => esc_html__('Header Logo Selection', 'quad-wp'),
            'desc' => esc_html__('Upload a new logo image', 'quad-wp'),
            'subtitle' => esc_html__('Replace or remove the existing logo', 'quad-wp'),
            'default' => array(
                'url' => get_template_directory_uri() . '/assets/images/logo.png')
        ),
        array(
            'id' => 'quad-header-menu-padding',
            'type' => 'slider',
            'title' => esc_html__('Header Height', 'quad-wp'),
            'subtitle' => esc_html__('Allows you to adjust header height. It is needed when the custom logo you add does not fit in the header.', 'quad-wp'),
            'desc' => esc_html__('If needed, adjust height until you are happy with how the logo fits in the header', 'quad-wp'),
            "default" => 0,
            "min" => 0,
            "step" => 1,
            "max" => 500,
            'display_value' => 'text'
        ),
        array(
            'id' => 'quad-header-menu-offset',
            'type' => 'slider',
            'title' => esc_html__('Header Menu Offset', 'quad-wp'),
            'subtitle' => esc_html__('Allows you to adjust menu position. It is needed when you want to adjust the menu position to the menu logo.', 'quad-wp'),
            "default" => 0,
            "min" => 0,
            "step" => 1,
            "max" => 500,
            'display_value' => 'text'
        ),
        array(
            'id' => 'quad-header-image',
            'type' => 'media',
            'url' => true,
            'title' => esc_html__('Page Header Default Image', 'quad-wp'),
            'desc' => esc_html__('Upload a new a new background image', 'quad-wp'),
            'subtitle' => esc_html__('Replace or remove the existing logo', 'quad-wp'),
            'default' => array(
                'url' => get_template_directory_uri() . '/assets/images/header-default.jpg')
        ),
    )
));
Redux::setSection($opt_name, array(
    'icon' => 'el-icon-credit-card',
    'title' => esc_html__('Footer', 'quad-wp'),
    'subsection' => false,
    'fields' => array(
        array(
            'id' => 'quad-footer-middle-switch',
            'type' => 'button_set',
            'title' => esc_html__('Footer widget area', 'quad-wp'),
            'subtitle' => esc_html__('Enable or disable footer widget area', 'quad-wp'),
            'desc' => esc_html__('Enable or disable footer widget area', 'quad-wp'),
            'options' => array(
                '1' => esc_html__('Enable', 'quad-wp'),
                '2' => esc_html__('Disable', 'quad-wp')
            ),
            'default' => '1'
        ),
        array(
            'id' => 'quad-footer-middle-layout',
            'type' => 'image_select',
            'required' => array('quad-footer-middle-switch', 'equals', '1'),
            'title' => esc_html__('Footer widget area Layout', 'quad-wp'),
            'subtitle' => esc_html__('Select the number of widgetable areas', 'quad-wp'),
            'options' => array(
                '1' => array(
                    'alt' => esc_html__('1 Area', 'quad-wp'),
                    'title' => '1',
                    'img' => get_template_directory_uri() . '/framework/admin/images/l1.png'
                ),
                '2' => array(
                    'alt' => esc_html__('2 Areas', 'quad-wp'),
                    'title' => '2',
                    'img' => get_template_directory_uri() . '/framework/admin/images/l2.png'
                ),
                '3' => array(
                    'alt' => esc_html__('3 Areas', 'quad-wp'),
                    'title' => '3',
                    'img' => get_template_directory_uri() . '/framework/admin/images/l3.png'
                ),
                '4' => array(
                    'alt' => esc_html__('4 Areas', 'quad-wp'),
                    'title' => '4',
                    'img' => get_template_directory_uri() . '/framework/admin/images/l4.png'
                )
            ),
            'default' => '4'
        ),
        array(
            'id' => 'quad-footer-middle-bg-switch',
            'type' => 'button_set',
            'title' => esc_html__('Footer background', 'quad-wp'),
            'subtitle' => esc_html__('Enable or disable background for footer area', 'quad-wp'),
            'desc' => esc_html__('Enable or disable background for footer areaa', 'quad-wp'),
            'options' => array(
                '1' => esc_html__('Enable', 'quad-wp'),
                '2' => esc_html__('Disable', 'quad-wp')
            ),
            'default' => '2'
        ),
        array('id' => 'quad-footer-middle-background',
            'type' => 'background',
            'required' => array('quad-footer-middle-bg-switch', 'equals', '1'),
            'title' => esc_html__('Footer Background', 'quad-wp'),
            'desc' => esc_html__('Select a color or image for the background', 'quad-wp'),
            'transparent' => false,
            'preview_media' => true,
            'default' => array(
                'background-color' => '',
                'background-repeat' => 'no-repeat',
                'background-position' => 'center center'
            )),
        array(
            'id' => 'quad-footer-bottom-switch',
            'type' => 'button_set',
            'title' => esc_html__('Footer Bottom widget area', 'quad-wp'),
            'subtitle' => esc_html__('Enable or disable footer widge area', 'quad-wp'),
            'desc' => esc_html__('Enable or disable footer widget area', 'quad-wp'),
            'options' => array(
                '1' => esc_html__('Enable', 'quad-wp'),
                '2' => esc_html__('Disable', 'quad-wp')
            ),
            'default' => '1'
        ),
        array(
            'id' => 'quad-footer-bottom-layout',
            'type' => 'image_select',
            'required' => array('quad-footer-bottom-switch', 'equals', '1'),
            'title' => esc_html__('Footer Bottom widget area Layout', 'quad-wp'),
            'subtitle' => esc_html__('Select the number of widgetable areas', 'quad-wp'),
            'options' => array(
                '1' => array(
                    'alt' => esc_html__('1 Area', 'quad-wp'),
                    'title' => '1',
                    'img' => get_template_directory_uri() . '/framework/admin/images/l1.png'
                ),
                '2' => array(
                    'alt' => esc_html__('2 Areas', 'quad-wp'),
                    'title' => '2',
                    'img' => get_template_directory_uri() . '/framework/admin/images/l2.png'
                ),
                '3' => array(
                    'alt' => esc_html__('3 Areas', 'quad-wp'),
                    'title' => '3',
                    'img' => get_template_directory_uri() . '/framework/admin/images/l3.png'
                ),
                '4' => array(
                    'alt' => esc_html__('4 Areas', 'quad-wp'),
                    'title' => '4',
                    'img' => get_template_directory_uri() . '/framework/admin/images/l4.png'
                )
            ),
            'default' => '2'
        ),
        array(
            'id' => 'quad-footer-bottom-bg-switch',
            'type' => 'button_set',
            'title' => esc_html__('Footer background', 'quad-wp'),
            'subtitle' => esc_html__('Enable or disable background for footer bottom area', 'quad-wp'),
            'desc' => esc_html__('Enable or disable background for footer bottom areaa', 'quad-wp'),
            'options' => array(
                '1' => esc_html__('Enable', 'quad-wp'),
                '2' => esc_html__('Disable', 'quad-wp')
            ),
            'default' => '2'
        ),
        array('id' => 'quad-footer-bottom-background',
            'type' => 'background',
            'required' => array('quad-footer-bottom-bg-switch', 'equals', '1'),
            'title' => esc_html__('Footer bottom background', 'quad-wp'),
            'desc' => esc_html__('Select a color or image for the background', 'quad-wp'),
            'transparent' => false,
            'preview_media' => true,
            'default' => array(
                'background-color' => '',
                'background-repeat' => 'no-repeat',
                'background-position' => 'center center'
            )),
    )
));

Redux::setSection($opt_name, array(
    'icon' => 'el-icon-list',
    'title' => esc_html__('Color Schemes', 'quad-wp'),
    'subsection' => false,
    'fields' => array(
        array(
            'id' => 'quad-accent-colors-enable',
            'type' => 'button_set',
            'title' => esc_html__('Color scheme', 'quad-wp'),
            'subtitle' => esc_html__('Enable or disable custom color scheme', 'quad-wp'),
            'desc' => esc_html__('If it is disabled, then the default color scheme will be used.', 'quad-wp'),
            'options' => array(
                '1' => esc_html__('Enable', 'quad-wp'),
                '2' => esc_html__('Disable', 'quad-wp')
            ),
            'default' => '2'
        ),
        array(
            'id' => 'quad-color-scheme-accent',
            'type' => 'color',
            'required' => array('quad-accent-colors-enable', 'equals', '1'),
            'title' => esc_html__('Accent color', 'quad-wp'),
            'subtitle' => esc_html__('Pick an accent color', 'quad-wp'),
            'default' => '#009cff',
            'transparent' => false,
            'validate' => 'color',
        ),
        array(
            'id' => 'quad-color-body-font',
            'type' => 'color',
            'required' => array('quad-accent-colors-enable', 'equals', '1'),
            'title' => esc_html__('Main font color', 'quad-wp'),
            'subtitle' => esc_html__('Pick a font color', 'quad-wp'),
            'default' => '#777',
            'transparent' => false,
            'validate' => 'color',
        ),
        array(
            'id' => 'quad-color-scheme-accent1',
            'type' => 'color',
            'required' => array('quad-accent-colors-enable', 'equals', '1'),
            'title' => esc_html__('Secondary font color 1', 'quad-wp'),
            'subtitle' => esc_html__('Pick a color', 'quad-wp'),
            'default' => '#31353a',
            'transparent' => false,
            'validate' => 'color',
        ),
        array(
            'id' => 'quad-color-scheme-accent2',
            'type' => 'color',
            'required' => array('quad-accent-colors-enable', 'equals', '1'),
            'title' => esc_html__('Secondary font color 2', 'quad-wp'),
            'subtitle' => esc_html__('Pick a color', 'quad-wp'),
            'default' => '#31363a',
            'transparent' => false,
            'validate' => 'color',
        ),
        array(
            'id' => 'quad-color-scheme-menu',
            'type' => 'color',
            'required' => array('quad-accent-colors-enable', 'equals', '1'),
            'title' => esc_html__('Menu font color', 'quad-wp'),
            'subtitle' => esc_html__('Pick a font color', 'quad-wp'),
            'default' => '#31363a',
            'transparent' => false,
            'validate' => 'color',
        ),
        array(
            'id' => 'quad-color-scheme-menu-background',
            'type' => 'color',
            'required' => array('quad-accent-colors-enable', 'equals', '1'),
            'title' => esc_html__('Menu background color', 'quad-wp'),
            'subtitle' => esc_html__('Pick a background color', 'quad-wp'),
            'default' => '#fff',
            'transparent' => false,
            'validate' => 'color',
        ),
        array(
            'id' => 'quad-color-scheme-submenu-font',
            'type' => 'color',
            'required' => array('quad-accent-colors-enable', 'equals', '1'),
            'title' => esc_html__('Submenus and megamenus font color', 'quad-wp'),
            'subtitle' => esc_html__('Pick a font color', 'quad-wp'),
            'default' => '#31363a',
            'transparent' => false,
            'validate' => 'color',
        ),
        array(
            'id' => 'quad-color-scheme-submenu-background',
            'type' => 'color',
            'required' => array('quad-accent-colors-enable', 'equals', '1'),
            'title' => esc_html__('Submenus and megamenus background color', 'quad-wp'),
            'subtitle' => esc_html__('Pick a background color', 'quad-wp'),
            'default' => '#fff',
            'transparent' => false,
            'validate' => 'color',
        ),
        array(
            'id' => 'quad-color-footer-font',
            'type' => 'color',
            'required' => array('quad-accent-colors-enable', 'equals', '1'),
            'title' => esc_html__('Footer font color', 'quad-wp'),
            'subtitle' => esc_html__('Pick a footer font color', 'quad-wp'),
            'default' => '#7a7a7a',
            'transparent' => false,
            'validate' => 'color',
        ),
        array(
            'id' => 'quad-color-footer-bottom-font',
            'type' => 'color',
            'required' => array('quad-accent-colors-enable', 'equals', '1'),
            'title' => esc_html__('Footer bottom font color', 'quad-wp'),
            'subtitle' => esc_html__('Pick a footer bottom font color', 'quad-wp'),
            'default' => '#565e67',
            'transparent' => false,
            'validate' => 'color',
        )
    )
));

/*
 * <--- END SECTIONS
 */

// Remove the demo link and the notice of integrated demo from the redux-framework plugin
function quad_remove_demo() {

    // Used to hide the demo mode link from the plugin page. Only used when Redux is a plugin.
    if (class_exists('ReduxFrameworkPlugin')) {
        remove_filter('plugin_row_meta', array(
            ReduxFrameworkPlugin::instance(),
            'plugin_metalinks'
                ), null, 2);

        // Used to hide the activation notice informing users of the demo panel. Only used when Redux is a plugin.
        remove_action('admin_notices', array(ReduxFrameworkPlugin::instance(), 'admin_notices'));
    }
}

// Adds the custom CSS and the custom color schemes 
function quad_theme_options_styles() {
    $custom_css='';
    
    if (!is_admin()) {
        global $quad_theme_options;

        if (is_admin_bar_showing()) {
            $custom_css.= '#header.stuck {padding-top: 40px;}';
        }

        if (isset($quad_theme_options['quad-font-switch'])) {

            if ($quad_theme_options['quad-font-switch'] == 1) {


                if (trim($quad_theme_options['quad-custom-font']) != '') {

                    $font_parts1 = explode("family=", $quad_theme_options['quad-custom-font']);
                    $font_parts2 = explode(":", $font_parts1[1]);

                    if (count($font_parts2) > 1) {
                        $font_family = $font_parts2[0];
                    } else {
                        $font_family = $font_parts2;
                    }

                    $font_family = str_replace("+", " ", $font_family);

                    if (is_array($font_family)) {
                        $custom_css.= 'body,
                            h1, 
                            h2, 
                            h3, 
                            h4, 
                            h5, 
                            h6,
                            .sf-menu a,
                            #wrap .woocommerce a.wc-backward,
                            #wrap .woocommerce a.button.checkout-button,
                            .woocommerce #wrap div.product form.cart .button,
                            .vertical-tabs-container.alt .tabs-menu li span
                        {font-family:"' . esc_attr($font_family[0]) . '";}';
                    } else {
                        $custom_css.= 'body,
                            h1, 
                            h2, 
                            h3, 
                            h4, 
                            h5, 
                            h6,
                            .sf-menu a,
                            #wrap .woocommerce a.wc-backward,
                            #wrap .woocommerce a.button.checkout-button,
                            .woocommerce #wrap div.product form.cart .button,
                            .vertical-tabs-container.alt .tabs-menu li span
                        {font-family:"' . esc_attr($font_family) . '";}';
                    }
                }

                if (trim($quad_theme_options['quad-custom-font2']) != '') {
                    $font_parts1 = explode("family=", $quad_theme_options['quad-custom-font2']);
                    $font_parts2 = explode(":", $font_parts1[1]);

                    if (count($font_parts2) > 1) {
                        $font_family = $font_parts2[0];
                    } else {
                        $font_family = $font_parts2;
                    }

                    $font_family = str_replace("+", " ", $font_family);

                    if (is_array($font_family)) {
                        $custom_css.= 'button,
                            input[type="reset"],
                            input[type="submit"],
                            input[type="button"],
                            .pricing-table-header p,
                            .pricing-table .btn,
                            a.social-icon.alt:after
                        {font-family:"' . esc_attr($font_family[0]) . '";}';
                    } else {
                        $custom_css.= 'button,
                            input[type="reset"],
                            input[type="submit"],
                            input[type="button"],
                            .pricing-table-header p,
                            .pricing-table .btn,
                            a.social-icon.alt:after
                        {font-family:"' . esc_attr($font_family[0]) . '";}';
                    }
                }
            }
        }

        $quad_header_padding = 0;

        if (isset($quad_theme_options['quad-header-menu-padding'])) {
            $quad_header_padding = $quad_theme_options['quad-header-menu-padding'];
        }

        if ($quad_header_padding != 0) {
            $custom_css.= '@media (min-width: 1025px) { #header-wrap { padding-top: ' . absint($quad_header_padding) . 'px; } }';
        }

        $quad_header_offset = 0;

        if (isset($quad_theme_options['quad-header-menu-offset'])) {
            $quad_header_offset = $quad_theme_options['quad-header-menu-offset'];
        }

        if ($quad_header_offset > 0) {
            $custom_css.= '@media (min-width: 1025px) { #header .sf-menu, #header #custom-search-button, #header .site-header-cart.menu { margin-top: ' . absint($quad_header_offset) . 'px; } }';
        }

        $quad_accent_colors_enable = 0;

        if (isset($quad_theme_options['quad-accent-colors-enable'])) {
            $quad_accent_colors_enable = $quad_theme_options['quad-accent-colors-enable'];
        }
        if ($quad_accent_colors_enable == 1) {

            $body_font = "#777";
            if (isset($quad_theme_options['quad-color-body-font'])) {
                if (preg_match('/(^#[0-9A-F]{6}$)|(^#[0-9A-F]{3}$)/i', $quad_theme_options['quad-color-body-font'])) {
                    $body_font = $quad_theme_options['quad-color-body-font'];
                }
            }

            if ($body_font != "#777") {

                $custom_css.= 'body,
                    .icon-box-2 .icon-box-content > a,
                    a.social-icon,
                    .vertical-tabs-container .tabs-menu li i,
                    .comment-meta a,
                    .widget_recent_entries ul li a,
                    .widget_pages ul li a,
                    .widget_archive ul li a,
                    .widget_categories a,
                    .widget_meta ul li a,
                    #recentcomments li a,
                    .widget_nav_menu a,
                    .quad_widget_contact_info ul li a,
                    .quad_widget_navigation li a,
                    .custom-color-selected .box.box-style-2,
                    .custom-color-selected a.social-icon
                    { color: ' . esc_attr($body_font) . '; }
                        .vertical-tabs-container .tabs-menu li i
                    { border-color: ' . esc_attr($body_font) . '; }';
            }

            $color_accent = "#009cff";
            if (isset($quad_theme_options['quad-color-scheme-accent'])) {
                if (preg_match('/(^#[0-9A-F]{6}$)|(^#[0-9A-F]{3}$)/i', $quad_theme_options['quad-color-scheme-accent'])) {
                    $color_accent = $quad_theme_options['quad-color-scheme-accent'];
                }
            }

            if ($color_accent != "#009cff") {

                $custom_css.= 'h1 a:hover, 
	h2 a:hover, 
	h3 a:hover, 
	h4 a:hover, 
	h5 a:hover, 
	h6 a:hover,
        blockquote.alt:before,
        blockquote h2,
        .text-highlight,
        a, 
	a:visited,
        ul.check li:before,
	ul.plus li:before,
	ul.pin li:before,
	ul.arrow-right li:before,
        .sf-menu > li.current > a,
	.sf-menu li.sfHover > a,
	.sf-menu a:hover,
	.sf-menu li.sfHover a:hover,
        nav .sf-menu li.current-menu-item > a,
        nav .sf-menu li.current-menu-parent > a,
        .sf-mega-section .comments-link a,
        #footer  a:hover,
        #footer-bottom  a:hover,
        .breadcrumb,
        h1.error,
        .question-mark:after,
        .headline h5,
        .headline.headline-large h1,
        .icon-box-1 > i,
        .icon-box-2 .icon-box-content a:hover,
        .icon-box-2:hover i,
        .icon-box-3 > i,
        .icon-box-4 > i,
        .icon-box-5 .icon-box-content h4 a,
        .milestone .milestone-value,
        .horizontal-process-builder li i,
        .horizontal-process-builder .process-description .process-number,
        .horizontal-process-builder li:hover i,
        .horizontal-process-builder li:hover  h5,
        .vertical-process-builder li .process-number,
        #wrap .woocommerce table.shop_table td.product-name a:hover,
        #wrap .woocommerce-checkout-review-order-table td.product-total,
        #wrap .woocommerce-checkout-review-order-table td.product-total,
        #wrap .woocommerce-checkout-review-order-table td span.woocommerce-Price-amount,
        .woocommerce #wrap div.product p.price, 
        .woocommerce #wrap div.product span.price,
        .woocommerce #wrap .star-rating span,
        #wrap .woocommerce .star-rating span,
        .vertical-tabs-container .tabs-menu li.active a,
        .vertical-tabs-container .tabs-menu li.active i,
        .testimonial span,
        .team-member-details p,
        .comments-link a,
        .widget_recent_entries ul li a:hover,
        .widget_pages ul li a:hover,
        .widget_archive ul li a:hover,
        .widget_categories a:hover,
        .widget_meta ul li a:hover,
        #recentcomments li a:hover,
        .widget_nav_menu .menu a:hover,
        .quad_widget_contact_info ul li i,
        .quad_widget_latest_posts ul li .title:hover,
        .quad_widget_latest_posts a,
        #footer .quad_widget_latest_posts ul li .title,
        #footer-bottom .quad_widget_latest_posts ul li .title,
        .quad_widget_navigation li a:hover,
        .custom-color-selected .icon-box-2 i,
        .custom-color-selected .vertical-tabs-container .tabs-menu li.active a,
        .custom-color-selected .portfolio-item-preview + .portfolio-item-description p:first-of-type,
        .custom-color-selected .quad_widget_latest_posts ul li .title,
        .custom-color-selected .headline h5,
        .icon-box-2 .icon-box-content > a,
        #content .portfolio-filter ul li a:hover,
	#content .portfolio-filter ul li a.active
                    { color: ' . esc_attr($color_accent) . '; }
                        button,
	input[type="reset"],
	input[type="submit"],
	input[type="button"],
        .search-overlay #custom-search-submit:hover,
        .theme-accordion.vc_tta-color-grey.vc_tta-style-flat .vc_tta-panel.vc_active .vc_tta-panel-title>a,
        .theme-accordion.vc_tta-color-grey.vc_tta-style-flat .vc_tta-panel .vc_tta-panel-title>a:hover,
        .alert.success,
        #content .btn,
        .dropcap.dropcap-square,
        .dropcap.dropcap-circle,
        .horizontal-process-builder li:hover i,
        .pricing-table-header p:before,
        .pricing-table-header p:after,
        .progress-bar .progress-bar-outer,
        .tp-bullets.custom .tp-bullet:hover,
	.tp-bullets.custom .tp-bullet.selected,
        .woocommerce #wrap ul.products li.product .button:hover,
        #wrap .woocommerce ul.products li.product .button:hover,
        .woocommerce #wrap #respond input#submit:hover, 
        .woocommerce #wrap button.button:hover, 
        .woocommerce #wrap input.button:hover,
        #wrap .woocommerce #respond input#submit:hover, 
        #wrap .woocommerce button.button:hover, 
        #wrap .woocommerce input.button:hover,
        .site-header-cart a.cart-contents .count,
        #wrap .woocommerce a.wc-backward,
        #wrap .woocommerce a.button.checkout-button,
        .woocommerce .page-numbers li .page-numbers:hover, 
	.woocommerce .page-numbers li .page-numbers.current,
        .woocommerce #wrap div.product form.cart .button,
        .woocommerce #wrap div.product .woocommerce-tabs ul.tabs li.active,
        a.social-icon.alt:after,
        a.social-icon.alt:hover,
        .theme-tabs.vc_tta-color-grey.vc_tta-tabs .vc_tta-tab.vc_active>a,
        .theme-tabs.vc_tta-color-grey.vc_tta-tabs .vc_tta-panel.vc_active .vc_tta-panel-title>a,
        .social-media a.social-icon,
        .team-member:hover .team-member-details,
        .thumbnails-slider .bx-prev,
        .thumbnails-slider .bx-next,
        .portfolio-slider:hover .bx-wrapper .bx-prev,
	.portfolio-slider:hover .bx-wrapper .bx-next,
        .sticky-post,
        .pagination .page-numbers:hover,
	.pagination .page-numbers.current,
        .widget_tag_cloud a,
        #wp-calendar tbody a,
        .custom-color-selected .icon-box-1 i,
        .custom-color-selected .team-member-details,
        #content .erp-pagination .page-numbers:hover,
	#content .erp-pagination .page-numbers.current
                    { background-color: ' . esc_attr($color_accent) . '; }
                        .sf-menu > li.dropdown ul li a:hover:before,
                    .sf-mega-section ul li a:hover:before,
                    .search-overlay #s:focus,
                    .search-overlay #custom-search-submit,
                    #content .btn:before,
                    .tp-leftarrow.custom:hover,
	.tp-rightarrow.custom:hover,
        .rev_slider_wrapper.alt .tp-leftarrow.custom:hover,
	.rev_slider_wrapper.alt .tp-rightarrow.custom:hover,
        #wrap .woocommerce a.wc-backward:before,
        #wrap .woocommerce a.button.checkout-button:before,
        .woocommerce #wrap div.product form.cart .button:before,
        .vertical-tabs-container .tabs-menu li.active i
                    { border-color: ' . esc_attr($color_accent) . '; }
                        .clients li:before,
                    .sf-arrows ul li:hover > .sf-with-ul:after 
                    { border-left-color: ' . esc_attr($color_accent) . '; }
                        .clients li:after
                    { border-right-color: ' . esc_attr($color_accent) . '; }
                        a.banner-image-container:before
                    { background-color: ' . esc_attr(quad_hex_to_rgba($color_accent, 0.4)) . '; }
                        #content .portfolio-item-overlay
                    { background-color: ' . esc_attr(quad_hex_to_rgba($color_accent, 0.7)) . '; }
                       #content a.btn{ color: #fff; }';
            }

            $color_accent1 = "#31353a";
            if (isset($quad_theme_options['quad-color-scheme-accent1'])) {
                if (preg_match('/(^#[0-9A-F]{6}$)|(^#[0-9A-F]{3}$)/i', $quad_theme_options['quad-color-scheme-accent1'])) {
                    $color_accent1 = $quad_theme_options['quad-color-scheme-accent1'];
                }
            }

            if ($color_accent1 != "#31353a") {

                $custom_css.= 'h1, 
                    h2, 
                    h3, 
                    h4, 
                    h5, 
                    h6,
                    h1 a, 
                    h2 a, 
                    h3 a, 
                    h4 a, 
                    h5 a, 
                    h6 a,
                    h1 a:visited, 
                    h2 a:visited, 
                    h3 a:visited, 
                    h4 a:visited, 
                    h5 a:visited, 
                    h6 a:visited,
                    .theme-accordion.vc_tta-color-grey.vc_tta-style-flat .vc_tta-panels .vc_tta-panel-body,
                    .icon-box-2 .icon-box-content h5 a,
                    .progress-bar-description,
                    .progress-bar .percentage,
                    .woocommerce #wrap ul.products li.product .price,
                    #wrap .woocommerce ul.products li.product .price,
                    .woocommerce #wrap ul.products li.product .button,
                    #wrap .woocommerce ul.products li.product .button,
                    .woocommerce #wrap #respond input#submit, 
                    .woocommerce #wrap button.button,
                    .woocommerce #wrap input.button,
                    #wrap .woocommerce #respond input#submit, 
                    #wrap .woocommerce button.button,
                    #wrap .woocommerce input.button,
                    .woocommerce .page-numbers li .page-numbers,
                    .vertical-tabs-container .tabs-menu li a,
                    .pagination .page-numbers,
                    .pagination .prev,
                    .pagination .next,
                    .custom-color-selected .portfolio-pagination .page-numbers,
                    .custom-color-selected .portfolio-pagination .prev,
                    .custom-color-selected .portfolio-pagination .next,
                    .erp-pagination .page-numbers,
                    .erp-pagination .prev,
                    .erp-pagination .next
                    { color: ' . esc_attr($color_accent1) . '; }
                        #content .btn.alt{ background-color: ' . esc_attr($color_accent1) . '; }
                            #content .btn.alt:before { border-color: ' . esc_attr($color_accent1) . '; }';
            }

            $color_accent2 = "#31363a";
            if (isset($quad_theme_options['quad-color-scheme-accent2'])) {
                if (preg_match('/(^#[0-9A-F]{6}$)|(^#[0-9A-F]{3}$)/i', $quad_theme_options['quad-color-scheme-accent2'])) {
                    $color_accent2 = $quad_theme_options['quad-color-scheme-accent2'];
                }
            }

            if ($color_accent2 != "#31363a") {

                $custom_css.= '#content .portfolio-item-details li span,
                    #content .portfolio-item-details li strong,
                    label,
                    input[type="text"],
                    input[type="password"],
                    input[type="date"],
                    input[type="datetime"],
                    input[type="datetime-local"],
                    input[type="month"],
                    input[type="week"],
                    input[type="email"],
                    input[type="number"],
                    input[type="search"],
                    input[type="tel"],
                    input[type="time"],
                    input[type="url"],
                    input[type="color"],
                    textarea,
                    .icon-box-2 > i,
                    .milestone .milestone-description,
                    .pie-chart i, 
                    .pie-chart .pie-chart-custom-text, 
                    .pie-chart .pie-chart-percent,
                    .pie-chart-description,
                    .pricing-table-header,
                    .vertical-tabs-container.alt .tabs-menu li i,
                    .byline a,
                    .comments-title,
                    .comment-reply-title,
                    .comment-author a,
                    .comment-author a:after,
                    .comment-form label,
                    .comment-form input[type="text"],
                    .comment-form input[type="email"],
                    .comment-form input[type="url"],
                    .comment-form textarea,
                    .quad_widget_latest_posts ul li .title,
                    #content .portfolio-filter ul li a
                    { color: ' . esc_attr($color_accent2) . '; }
                        #searchsubmit { background-color: ' . esc_attr($color_accent2) . '; }';
            }

            $menu_font = "#31363a";

            if (isset($quad_theme_options['quad-color-scheme-menu'])) {
                if (preg_match('/(^#[0-9A-F]{6}$)|(^#[0-9A-F]{3}$)/i', $quad_theme_options['quad-color-scheme-menu'])) {
                    $menu_font = $quad_theme_options['quad-color-scheme-menu'];
                }
            }

            if ($menu_font != "#31363a") {
                $custom_css.= '.sf-menu a,
                    .sf-menu > li > a,
                    .sf-menu > li.dropdown > a,
                    .sf-mega-section .byline a
                    { color: ' . esc_attr($menu_font) . '; }';
            }

            $menu_background = "#fff";

            if (isset($quad_theme_options['quad-color-scheme-menu-background'])) {
                if (preg_match('/(^#[0-9A-F]{6}$)|(^#[0-9A-F]{3}$)/i', $quad_theme_options['quad-color-scheme-menu-background'])) {
                    $menu_background = $quad_theme_options['quad-color-scheme-menu-background'];
                }
            }

            if ($menu_background != "#fff") {
                $custom_css.= '#header,#header #custom-search-form #s,#header.stuck
                    { background-color: ' . esc_attr($menu_background) . '; }';
            }

            $submenu_font = "#31363a";

            if (isset($quad_theme_options['quad-color-scheme-submenu-font'])) {
                if (preg_match('/(^#[0-9A-F]{6}$)|(^#[0-9A-F]{3}$)/i', $quad_theme_options['quad-color-scheme-submenu-font'])) {
                    $submenu_font = $quad_theme_options['quad-color-scheme-submenu-font'];
                }
            }

            if ($submenu_font != "#31363a") {

                $custom_css.= '.sf-menu a, .sf-mega { color: ' . esc_attr($submenu_font) . '; }
                .sf-menu > li.dropdown  ul li a:before,.sf-mega-section ul a:before { border-color: ' . esc_attr($submenu_font) . '; }
                .sf-arrows ul .sf-with-ul:after { border-left-color: ' . esc_attr($submenu_font) . '; }';
            }

            $submenu_background = "#fff";

            if (isset($quad_theme_options['quad-color-scheme-submenu-background'])) {
                if (preg_match('/(^#[0-9A-F]{6}$)|(^#[0-9A-F]{3}$)/i', $quad_theme_options['quad-color-scheme-submenu-background'])) {
                    $submenu_background = $quad_theme_options['quad-color-scheme-submenu-background'];
                }
            }

            if ($submenu_background != "#fff") {
                $custom_css.= '.sf-menu li.dropdown ul, .sf-mega
                    { background-color: ' . esc_attr($submenu_background) . '; }';
            }

            $footer_font = "#7a7a7a";

            if (isset($quad_theme_options['quad-color-footer-font'])) {
                if (preg_match('/(^#[0-9A-F]{6}$)|(^#[0-9A-F]{3}$)/i', $quad_theme_options['quad-color-footer-font'])) {
                    $footer_font = $quad_theme_options['quad-color-footer-font'];
                }
            }

            if ($footer_font != "#7a7a7a") {
                $custom_css.= '#footer,
                    #footer .widget-title,
                    #footer h1, 
                    #footer a,
                        #footer h2, 
                        #footer h3, 
                        #footer h4, 
                        #footer h5, 
                        #footer h6,
                        #footer .widget_pages ul li:after,
                        #footer .widget_rss .rsswidget,
                        #footer .mc4wp-form input[type="email"],
                        #footer .quad_widget_latest_posts ul li .title
                        { color: ' . esc_attr($footer_font) . '; }
                            #footer .quad_widget_latest_posts ul li
                        { border-bottom-color: ' . esc_attr($footer_font) . '; }';
            }

            $footer_bottom_font = "#565e67";

            if (isset($quad_theme_options['quad-color-footer-bottom-font'])) {
                if (preg_match('/(^#[0-9A-F]{6}$)|(^#[0-9A-F]{3}$)/i', $quad_theme_options['quad-color-footer-bottom-font'])) {
                    $footer_bottom_font = $quad_theme_options['quad-color-footer-bottom-font'];
                }
            }

            if ($footer_bottom_font != "#565e67") {
                $custom_css.= '#footer-bottom,
                    #footer-bottom .widget-title,
                    #footer-bottom h1, 
                    #footer-bottom a,
                        #footer-bottom h2, 
                        #footer-bottom h3, 
                        #footer-bottom h4, 
                        #footer-bottom h5, 
                        #footer-bottom h6,
                        #footer-bottom .widget_pages ul li:after,
                        #footer-bottom .widget_rss .rsswidget,
                        #footer-bottom .mc4wp-form input[type="email"],
                        #footer-bottom .quad_widget_latest_posts ul li .title
                        { color: ' . esc_attr($footer_bottom_font) . '; }
                            #footer-bottom .quad_widget_latest_posts ul li
                        { border-bottom-color: ' . esc_attr($footer_bottom_font) . '; }';
            }
        }

        $boxed_size = 1340;

        if (isset($quad_theme_options['quad-boxed-size'])) {
            $boxed_size = $quad_theme_options['quad-boxed-size'];
        }

        if ($boxed_size != 1340) {
            $custom_css.= '@media (min-width: 1200px) { body.boxed #wrap, body.boxed #header.stuck { max-width: ' . esc_attr($boxed_size) . 'px; }';
        }

        $quad_boxed_color = $quad_boxed_image = $quad_boxed_repeat = $quad_boxed_position = $quad_boxed_size = $quad_boxed_attachment = '';

        if (isset($quad_theme_options['quad-boxed-background']['background-color'])) {
            $quad_boxed_color = $quad_theme_options['quad-boxed-background']['background-color'];
        }

        if (isset($quad_theme_options['quad-boxed-background']['background-image'])) {
            $quad_boxed_image = $quad_theme_options['quad-boxed-background']['background-image'];
        }

        if (isset($quad_theme_options['quad-boxed-background']['background-repeat'])) {
            $quad_boxed_repeat = $quad_theme_options['quad-boxed-background']['background-repeat'];
        }

        if (isset($quad_theme_options['quad-boxed-background']['background-position'])) {
            $quad_boxed_position = $quad_theme_options['quad-boxed-background']['background-position'];
        }

        if (isset($quad_theme_options['quad-boxed-background']['background-size'])) {
            $quad_boxed_size = $quad_theme_options['quad-boxed-background']['background-size'];
        }

        if (isset($quad_theme_options['quad-boxed-background']['background-attachment'])) {
            $quad_boxed_attachment = $quad_theme_options['quad-boxed-background']['background-attachment'];
        }

        if ($quad_boxed_color != null || $quad_boxed_image != null) {
            $custom_css.= ' body.boxed {';
            if ($quad_boxed_color != null) {
                $custom_css.= 'background-color: ' . esc_attr($quad_boxed_color) . ';';
            }

            // Background image.
            if ($quad_boxed_image != null) {
                $custom_css.= 'background-image: url(' . esc_url($quad_boxed_image) . ');';
            }

            // Background image options
            if ($quad_boxed_repeat != null) {
                $custom_css.= 'background-repeat: ' . esc_attr($quad_boxed_repeat) . ';';
            }
            if ($quad_boxed_position != null) {
                $custom_css.= 'background-position: ' . esc_attr($quad_boxed_position) . ';';
            }
            if ($quad_boxed_size != null) {
                $custom_css.= 'background-size: ' . esc_attr($quad_boxed_size) . ';';
            }
            if ($quad_boxed_attachment != null) {
                $custom_css.= 'background-attachment: ' . esc_attr($quad_boxed_attachment) . ';';
            }

            $custom_css.= '}';
        }

        $quad_footer_middle_bg_enable = 0;
        if (isset($quad_theme_options['quad-footer-middle-bg-switch'])) {
            $quad_footer_middle_bg_enable = $quad_theme_options['quad-footer-middle-bg-switch'];
        }

        if ($quad_footer_middle_bg_enable == 1) {
            $quad_footer_middle_color = $quad_footer_middle_image = $quad_footer_middle_repeat = $quad_footer_middle_position = $quad_footer_middle_size = $quad_footer_middle_attachment = '';

            if (isset($quad_theme_options['quad-footer-middle-background'] ['background-color'])) {
                $quad_footer_middle_color = $quad_theme_options ['quad-footer-middle-background']['background-color'];
            }

            if (isset($quad_theme_options ['quad-footer-middle-background']['background-image'])) {
                $quad_footer_middle_image = $quad_theme_options['quad-footer-middle-background'] ['background-image'];
            }

            if (isset($quad_theme_options['quad-footer-middle-background'] ['background-repeat'])) {
                $quad_footer_middle_repeat = $quad_theme_options ['quad-footer-middle-background'] ['background-repeat'];
            }

            if (isset($quad_theme_options['quad-footer-middle-background'] ['background-position'])) {
                $quad_footer_middle_position = $quad_theme_options['quad-footer-middle-background'] ['background-position'];
            }

            if (isset($quad_theme_options ['quad-footer-middle-background'] ['background-size'])) {
                $quad_footer_middle_size = $quad_theme_options['quad-footer-middle-background'] ['background-size'];
            }

            if (isset($quad_theme_options['quad-footer-middle-background'] ['background-attachment'])) {
                $quad_footer_middle_attachment = $quad_theme_options['quad-footer-middle-background'] ['background-attachment'];
            }

            if ($quad_footer_middle_color != null || $quad_footer_middle_image != null) {
                $custom_css.= ' #footer {';
                if ($quad_footer_middle_color != null) {
                    $custom_css.= 'background-color: ' . esc_attr($quad_footer_middle_color) . ';';
                }

                if ($quad_footer_middle_image != null) {
                    $custom_css.= 'background-image: url(' . esc_url($quad_footer_middle_image) . ');';
                }

                if ($quad_footer_middle_repeat != null) {
                    $custom_css.= 'background-repeat: ' . esc_attr($quad_footer_middle_repeat) . ';';
                }
                if ($quad_footer_middle_position != null) {
                    $custom_css.= 'background-position: ' . esc_attr($quad_footer_middle_position) . ';';
                }
                if ($quad_footer_middle_size != null) {
                    $custom_css.= 'background-size: ' . esc_attr($quad_footer_middle_size) . ';';
                }
                if ($quad_footer_middle_attachment != null) {
                    $custom_css.= 'background-attachment: ' . esc_attr($quad_footer_middle_attachment) . ';';
                }

                $custom_css.= '}';
            }
        }

        $quad_footer_bottom_bg_enable = 0;
        if (isset($quad_theme_options['quad-footer-bottom-bg-switch'])) {
            $quad_footer_bottom_bg_enable = $quad_theme_options['quad-footer-bottom-bg-switch'];
        }

        if ($quad_footer_bottom_bg_enable == 1) {
            $quad_footer_bottom_color = $quad_footer_bottom_image = $quad_footer_bottom_repeat = $quad_footer_bottom_position = $quad_footer_bottom_size = $quad_footer_bottom_attachment = '';

            if (isset($quad_theme_options['quad-footer-bottom-background'] ['background-color'])) {
                $quad_footer_bottom_color = $quad_theme_options ['quad-footer-bottom-background']['background-color'];
            }

            if (isset($quad_theme_options ['quad-footer-bottom-background']['background-image'])) {
                $quad_footer_bottom_image = $quad_theme_options['quad-footer-bottom-background'] ['background-image'];
            }

            if (isset($quad_theme_options['quad-footer-bottom-background'] ['background-repeat'])) {
                $quad_footer_bottom_repeat = $quad_theme_options ['quad-footer-bottom-background'] ['background-repeat'];
            }

            if (isset($quad_theme_options['quad-footer-bottom-background'] ['background-position'])) {
                $quad_footer_bottom_position = $quad_theme_options['quad-footer-bottom-background'] ['background-position'];
            }

            if (isset($quad_theme_options ['quad-footer-bottom-background'] ['background-size'])) {
                $quad_footer_bottom_size = $quad_theme_options['quad-footer-bottom-background'] ['background-size'];
            }

            if (isset($quad_theme_options['quad-footer-bottom-background'] ['background-attachment'])) {
                $quad_footer_bottom_attachment = $quad_theme_options['quad-footer-bottom-background'] ['background-attachment'];
            }

            if ($quad_footer_bottom_color != null || $quad_footer_bottom_image != null) {
                $custom_css.= ' #footer-bottom {';
                if ($quad_footer_bottom_color != null) {
                    $custom_css.= 'background-color: ' . esc_attr($quad_footer_bottom_color) . ';';
                }

                if ($quad_footer_bottom_image != null) {
                    $custom_css.= 'background-image: url(' . esc_url($quad_footer_bottom_image) . ');';
                }

                if ($quad_footer_bottom_repeat != null) {
                    $custom_css.= 'background-repeat: ' . esc_attr($quad_footer_bottom_repeat) . ';';
                }
                if ($quad_footer_bottom_position != null) {
                    $custom_css.= 'background-position: ' . esc_attr($quad_footer_bottom_position) . ';';
                }
                if ($quad_footer_bottom_size != null) {
                    $custom_css.= 'background-size: ' . esc_attr($quad_footer_bottom_size) . ';';
                }
                if ($quad_footer_bottom_attachment != null) {
                    $custom_css.= 'background-attachment: ' . esc_attr($quad_footer_bottom_attachment) . ';';
                }

                $custom_css.= '}';
            }
        }

        /* Theme options custom css related field */
        $quad_custom_css = "";
        if (isset($quad_theme_options['quad-custom-css'])) {
            $custom_css.= $quad_theme_options['quad-custom-css'];
        }
    }
    
    return $custom_css;
}

function quad_hex_to_rgba($color, $opacity = false) {

    $default = 'rgb(0,0,0)';

    //Return default if no color provided
    if (empty($color))
        return $default;

    //Sanitize $color if "#" is provided 
    if ($color[0] == '#') {
        $color = substr($color, 1);
    }

    //Check if color has 6 or 3 characters and get values
    if (strlen($color) == 6) {
        $hex = array($color[0] . $color[1], $color[2] . $color[3], $color[4] . $color[5]);
    } elseif (strlen($color) == 3) {
        $hex = array($color[0] . $color[0], $color[1] . $color[1], $color[2] . $color[2]);
    } else {
        return $default;
    }

    //Convert hexadec to rgb
    $rgb = array_map('hexdec', $hex);

    //Check if opacity is set(rgba or rgb)
    if ($opacity) {
        if (abs($opacity) > 1)
            $opacity = 1.0;
        $output = 'rgba(' . implode(",", $rgb) . ',' . $opacity . ')';
    } else {
        $output = 'rgb(' . implode(",", $rgb) . ')';
    }

    //Return rgb(a) color string
    return $output;
}
