<?php
/**
 * The Header template for quad theme
 */
if (!defined('ABSPATH')) {
    exit();
}
?>
<!DOCTYPE html>
<html <?php language_attributes(); ?>>

    <head>
        <link rel="pingback" href="<?php bloginfo('pingback_url'); ?>">

        <meta charset="<?php echo esc_attr(bloginfo('charset')); ?>">
        <meta name="viewport" content="width=device-width, initial-scale=1, maximum-scale=1, user-scalable=0"/> 

        <?php wp_head(); ?>
    </head>

    <body <?php body_class(); ?>>

        <?php
        $relevant_id = quad_relevant_id();

        $header_text = $font_color = $pbg_color = $sbg_color = $boxed = $animations = $breadcrumbs = '';

        if (class_exists('ReduxFramework')) {
            $default_image=quad_options_var('quad-header-image');
            $image_header[0] = $default_image['url'];
        } else {
            $image_header[0] = get_template_directory_uri() . '/assets/images/header-default.jpg';
        }

        if (is_search()) {
            $header_text = sprintf(esc_html__('The search for %s returned:', 'quad-wp'), get_search_query());
            $page_header_toggle = 'header_on';
        } else if (is_404()) {
            $header_text = sprintf(esc_html__('404 Not found', 'quad-wp'), get_search_query());
            $page_header_toggle = 'header_on';
        } else {
            $page_header_toggle = get_post_meta($relevant_id, 'quad_header_toggle', true);
            if ($page_header_toggle == null) {
                update_post_meta($relevant_id, 'quad_header_toggle', 'header_on');
                update_post_meta($relevant_id, 'quad_header_title', get_the_title($relevant_id));
                $page_header_toggle = 'header_on';
            }

            if ($page_header_toggle == 'header_on') {
                $header_text = get_post_meta($relevant_id, 'quad_header_title', true);
                if ($header_text == null && is_front_page()) {
                    $header_text = esc_html__('Home', 'quad-wp');
                }
                $font_color = get_post_meta($relevant_id, 'quad_header_font_color', true);
                $pbg_color = get_post_meta($relevant_id, 'quad_header_pbg_color', true);
                if ($pbg_color != null) {
                    $image_header[0] = '';
                }

                $header_image_id = get_post_meta($relevant_id, 'quad_header_image', true);
                $boxed = get_post_meta($relevant_id, 'quad_page_boxed', true);
                if ($header_image_id != null) {
                    $image_header = wp_get_attachment_image_src($header_image_id, 'full');
                }
                $breadcrumbs_color = get_post_meta($relevant_id, 'quad_header_breadcrumbs_color', true);
                $breadcrumbs = get_post_meta($relevant_id, 'quad_header_breadcrumbs', true);
                $animations = get_post_meta($relevant_id, 'quad_header_animation', true);
            }
        }
        ?>  

        <div id="wrap">

            <div id="header-wrap">

                <div id="header">                        

                    <!-- /// HEADER  //////////////////////////////////////////////////////////////////////////////////////////////////////////// -->

                    <div class="container">
                        <div class="row">
                            <div class="span3">

                                <!-- // Logo // -->
                                <div id="logo">
                                    <a href="<?php echo esc_url(home_url('/')); ?>">
                                        <img src="<?php
                                        if (quad_options_var('quad-header-logo') != '') {
                                            $logo = quad_options_var('quad-header-logo');
                                            echo esc_url($logo['url']);
                                        } else {
                                            echo esc_url(get_template_directory_uri() . '/assets/images/logo.png');
                                        }
                                        ?>" alt="<?php esc_html_e('Home', 'quad-wp'); ?>">
                                    </a>
                                </div>

                            </div><!-- end .span3 -->
                            <div class="span9">

                                <?php if (quad_options_var('quad-header-search-toggle') == 1) { ?>
                                    <a id="custom-search-button" href="#"></a>
                                    <?php
                                }
                                if (quad_options_var('quad-cart-toggle') == 1 && class_exists('woocommerce')) {
                                    ?>
                                    <!-- // Shopping Cart trigger // -->         
                                    <ul class="site-header-cart menu" id="shopping-cart">
                                        <li>
                                            <a title="<?php esc_html_e('View your shopping cart', 'quad-wp'); ?>" href="<?php
                                            global $woocommerce;
                                            echo esc_url($woocommerce->cart->get_checkout_url());
                                            ?>" class="cart-contents">
                                                <span class="count"><?php echo WC()->cart->get_cart_contents_count(); ?></span>
                                            </a>
                                        </li>
                                    </ul>
                                <?php } ?>

                                <nav>
                                    <?php
                                    // Wordpress navigation menu
                                    if (has_nav_menu('quad-main-nav-menu')) {
                                        wp_nav_menu(array(
                                            'theme_location' => 'quad-main-nav-menu',
                                            'container' => false,
                                            'fallback_cb' => false,
                                            'items_wrap' => '<ul id="menu" class="sf-menu fixed">%3$s</ul>',
                                            'walker' => new quad_Nav_Menu_Walker())
                                        );
                                    } else {
                                        ?>
                                        <!-- // Menu // -->
                                        <ul id="menu" class="sf-menu fixed">
                                            <li>
                                                <a class="quad-no-menu" href="<?php echo esc_url(admin_url('nav-menus.php')); ?>">
                                                    <p><?php echo esc_html__('Please select a menu from Appearence > Menus', 'quad-wp'); ?></p>
                                                </a>
                                            </li>
                                        </ul>
                                    <?php } ?>
                                </nav>

                                <?php if (quad_options_var('quad-header-search-toggle') == 1) { ?>
                                    <!-- // Custom search // -->             
                                    <div class="search-overlay overlay-door">

                                        <button type="button" class="search-overlay-close">Close</button>

                                        <form action="<?php echo esc_url(home_url('/')); ?>" id="custom-search-form" method="get" role="search">
                                            <input type="text" value="" name="s" id="s" placeholder="<?php esc_html_e('type and press enter to search...', 'quad-wp'); ?>">
                                            <input type="submit" id="custom-search-submit" value="search">
                                        </form>

                                    </div>
                                <?php } ?>

                                <!-- // Mobile menu trigger // -->
                                <a href="#" id="mobile-menu-trigger">
                                    <i class="fa fa-bars"></i>
                                </a>

                            </div><!-- end .span9 -->
                        </div><!-- end .row -->		
                    </div><!-- end .container -->

                    <!-- //////////////////////////////////////////////////////////////////////////////////////////////////////////////////////// -->

                </div><!-- end #header -->
            </div><!-- end #header-wrap -->	
            <div id="content">
                <?php  if ($page_header_toggle == 'header_on') : ?>
                    <div id="page-header" <?php
                    if ($image_header[0] != null || $pbg_color != null) {
                        echo ' style="';
                        if ($pbg_color != null || $image_header[0] != null) {
                            if ($pbg_color != null) {
                                echo 'background-color:' . esc_attr($pbg_color) . ';';
                            }
                            if ($image_header[0] != null) {
                                echo "background-image: url('" . esc_url($image_header[0]) . "');";
                            }
                        }
                        echo '"';
                    }
                    ?>>

                        <div class="container">
                            <div class="row">
                                <div class="span12">

                                    <h1 <?php
                                    if ($animations != 'disable') {
                                        echo 'class="animate" data-animation="slideInLeft" data-animation-delay="100" data-animation-speed="1000"';
                                    }
                                    if ($font_color != null) {
                                        echo ' style="color:' . esc_attr($font_color) . ';"';
                                    }
                                    ?>><?php echo esc_html($header_text); ?></h1>

                                    <?php if ($breadcrumbs == 'breadcrumbs') { ?>
                                        <div <?php
                                        if ($animations != 'disable') {
                                            echo 'class="animate" data-animation="slideInLeft" data-animation-delay="100" data-animation-speed="1000"';
                                        }
                                        if ($breadcrumbs_color != null) {
                                            echo ' style="color:' . esc_attr($breadcrumbs_color) . ';"';
                                        }
                                        ?>><?php
                                                if ($breadcrumbs_color != null) {
                                                    quad_breadcrumbs(array('separator_icon' => ' / ', 'breadcrumbs_classes' => 'breacrumbs-color breadcrumb quad-breadcrumbs', 'color' => $breadcrumbs_color));
                                                } else {
                                                    quad_breadcrumbs(array('separator_icon' => ' / ',));
                                                }
                                                ?>
                                        </div>
                                    <?php } ?>
                                </div><!-- end .span12 -->
                            </div><!-- end .row -->
                        </div><!-- end .container -->

                    </div>
                    <?php
                endif;
                 $fullwidth = 0;
                if (is_search()) {
                    $sidebar_position = quad_options_var('quad-search-sidebar-position');
                    $fullwidth = 0;
                } else {
                    $sidebar_position = get_post_meta($relevant_id, 'quad_sidebar_position', true);

                    if ($relevant_id == 0) {
                        $sidebar_position = 'right';
                    }
                    if (defined('WPB_VC_VERSION')) {
                        $vc_enabled = get_post_meta($relevant_id, '_wpb_vc_js_status', true);
                    } else {
                        $vc_enabled = null;
                    }

                    if ($vc_enabled=='true') {
                        $fullwidth = 1;
                    } else {
                        
                        if( get_post_meta($relevant_id, 'quad_fullwidth_enable', true)=='1'){
                             $fullwidth = 1;
                             
                        }
                    }
                }

                if (!empty($sidebar_position) && $sidebar_position != 'none') {

                    if ($fullwidth == 0) {
                        echo '<div class="container quad-content">';
                    } else {
                        echo '<div class="full-section">';
                    }
                    echo '<div class="row">';

                    if ($sidebar_position == 'left') {
                        get_sidebar();
                    }

                    echo '<div class="span9">';
                } else if ($fullwidth == 0) {
                    echo '<div class="container quad-content"><div class="row"><div class="span12">';
                } 